# Attrs


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**language** | **str** |  | [optional] 

## Example

```python
from src.client.generated.models.attrs import Attrs

# TODO update the JSON string below
json = "{}"
# create an instance of Attrs from a JSON string
attrs_instance = Attrs.from_json(json)
# print the JSON string representation of the object
print(Attrs.to_json())

# convert the object into a dict
attrs_dict = attrs_instance.to_dict()
# create an instance of Attrs from a dict
attrs_from_dict = Attrs.from_dict(attrs_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


